
%%                                                        STAGtimedat  6.1
 
%                                                  plots StagYY's time.dat 
%    . calls f_background
%    . calls f_defaultsTimedat
%    . calls f_dimParameter
%    . calls f_figStyle
%    . calls f_importData
%    . calls f_importTimedat
%    . calls f_saveFig
%                                               12.12.2015  Fabio Crameri

%% UPDATES >5.0
% *implemented into StagLab*
% *more time.dat parameters added*
% *code simmplifications*
% *bug fixes to dimensionalisation*

%% NOTES
% Be careful with dimensionalisation! Might need some further checking.

function [SAVE] = STAGtimedat(IN,PLOT,SWITCH,STYLE,SAVE)
if exist('IN','var') %if run from a parfile
    %% DEFAULT VARIABLES
    %...see f_defaultsTimedat.m
else
    clear; clf;
    %% INPUT (...use parameter file instead)
    SAVE.StartNum = 1; SAVE.EndNum = 1;
    [IN,PLOT,SWITCH,STYLE,SAVE] = f_defaultsTimedat; %get default variables
    IN.fname_vector   	=   {  'testDIM'  'testDIM' };	% filename
    IN.number_vector    =   [   2           2 	];
    IN.parameter_vector =   [   11          11 	];
    IN.folder_vector	=   {   '/work/plotTest/' ...
                                '/work/plotTest/'    };    
end

%% STARTUP PROCEDURE
SAVE.app = 'STAGtimedat'; SAVE.appVersion = '6.1';
if ~isfield(SAVE,'count'); SAVE.count = 0; end
[SAVE,SWITCH] = f_startup(PLOT,SAVE,SWITCH);

%% SETUP FIGURE
clf(figure(1))
colordef(figure(1),STYLE.colorMode)

h_runs = zeros(size(IN.fname_vector,2),1);
for irun=1:size(IN.fname_vector,2)
    clearvars -except IN PLOT SWITCH STYLE SAVE irun h_runs
    
    %% VARIABLE CONVERSION & SETUP
    FILE.name         	= IN.fname_vector{irun};
    folder              = IN.folder_vector{irun};
    SWITCH.parameter    = IN.parameter_vector(irun);
    line_color          = PLOT.ColorVector(irun,:);
    
    nr_plots=0;                                                               % rprof label
    if IN.plotTemperature;  	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'Tmean'}; end
    if IN.plotViscosity;      	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'eta_mean'}; end
    if IN.plotVelocity;     	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'Vrms'}; end
    if IN.plotRa_eff;       	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'ra_eff'}; end
    if IN.plotNu_top;       	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'Nu_top'}; end
    if IN.plotNu_bot;        	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'Nu_bot'}; end
    if IN.plotInternalHeating;	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'H_int'}; end
    if IN.plotComposition;      nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'C_mean'}; end
    if IN.plotHeatfluxTop;    	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'F_bot'}; end
    if IN.plotHeatfluxBot;    	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'F_top'}; end
    if IN.plotEruptionRate;   	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'erupt_rate'}; end
    if IN.plotEruptHeatFlux;   	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'erupt_heatflux'}; end
    if IN.plotErupta;           nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'erupta'}; end
    if IN.plotEntrainment;  	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'entrainment'}; end
    if IN.plotCmass_error;      nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'Cmass_error'}; end
    if IN.plotTimesteps;    	nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'istep'}; end
    if IN.plotPerformance;      nr_plots = nr_plots+1; DATA.string(1,nr_plots)={'istep'}; end

    %% CHECK FOR DIRECTORY
    folder_op       = strcat(folder,'+op/');
    folder_im       = strcat(folder,'+im/');
    FILE.directory  = [folder_op,FILE.name,'/']; %needed for f_dimParameter
    filestem        = strcat(folder_op,FILE.name,'/',FILE.name,'_time.dat');
    if ~exist(filestem,'file')
        display(filestem)
        error('file not found: CHECK FILESTEM!')
    end

    %% OPEN FILE and check its length
    %find number of header entries in first line automatically
    data_1 = fopen(filestem,'r');
    nHeaders=0;
    entry=1;
    while (entry ~= '0')
        entry = fscanf(data_1,'%s',[1 1]);
        nHeaders = nHeaders+1;
        DATA.title{1,nHeaders} = entry;
    end
    fclose(data_1);
    DATA.title(:,end) = [];
    nHeaders=nHeaders-1;
    
    if IN.checkFileSize
        %find number of numeric entries in one line automatically
        data_1 = fopen(filestem,'r');
        header1 = fgets(data_1); %skip header
        nHeaders=0;
        entry=0;
        while (nHeaders<=n_headers || entry~=1)  %there could be an entry~=1 somewhere else the timestep...
            entry = fscanf(data_1,'%e',[1 1]);
            nHeaders = nHeaders+1;
        end
        fclose(data_1);
        nHeaders=nHeaders-1;
        n = nHeaders;

        %find line number automatically
        data_1 = fopen(filestem,'r');
        nLines = 0;
        while (fgets(data_1) ~= -1)
            nLines = nLines+1;
        end
        fclose(data_1);
        nr_time_steps = nLines;  % #data in z-direction

        display(['datafile is ',num2str(n),' x ',num2str(nLines)])
    end
    
    %% IMPORT & READING DATA
    if nHeaders==27 || nHeaders==17 %new or old files 
        DATA.filename = filestem;
        [DATA] = f_importTimedat(DATA);
    else
        error('number of columns in time.dat is different from standard format!')
    end
    nColumns    = size(DATA.Array,2);
    nRows       = size(DATA.Array{1},1);
    
    %% DISPLAY MODEL DETAILS I
    display(['Name:              ',FILE.name])
    if SWITCH.me
        % display(['datafile is ',num2str(n),' x ',num2str(nLines)])
        display(['Data Structure:       __',num2str(nColumns),'__>'])
        display('                     |')
        display(['                   ',num2str(nRows)])
        display('                     |')
        display('                     V')
    end
    
    %% CHECK FOR DIMENSIONAL INPUT:
    %get time after first timestep
    dummy = DATA.Array{strcmp(DATA.title,'time')}(2,1);
    if dummy>1e2  %if first timestep > 100 (years) then DIMENSIONAL INPUT
        SWITCH.dimensional_input = true; display('Input:             dimensional');
        SWITCH.dim = true; %set output to dimensional if input is dimensional
    else
        SWITCH.dimensional_input = false; display('Input:             non-dimensional');
    end
    
    %% DIMENSIONALIZATION
    [SETUP,SWITCH] = f_dimParameter(SWITCH,FILE);
    
    % SET TIME
    timeRow          	= find(strcmp(DATA.title,'time')); 
    PLOT.time         	= DATA.Array{1,timeRow};
    PLOT.time_dim     	= DATA.Array{1,timeRow}*SETUP.timescale/SETUP.secyear;  %get dimensional time [a]
    
    dummy = max(PLOT.time_dim); %[a]
    if dummy>100*1e6 %>100Ma
        PLOT.time2plot = PLOT.time_dim/1e9; PLOT.time2plotDim = 'Ga'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e9;
    elseif dummy<1e-3 %<0.001a
        PLOT.time2plot = PLOT.time_dim*SETUP.secyear; PLOT.time2plotDim = 's'; PLOT.timeConvert = SETUP.timescale;
    elseif dummy<1e2 %<100a
        PLOT.time2plot = PLOT.time_dim; PLOT.time2plotDim = 'a'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear;
    elseif dummy<1e5 %<0.1Ma
        PLOT.time2plot = PLOT.time_dim/1e3; PLOT.time2plotDim = 'ka'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e3;
    else
        PLOT.time2plot = PLOT.time_dim/1e6; PLOT.time2plotDim = 'Ma'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e6;
    end
    if ~SWITCH.dim && ~SWITCH.dimensional_input; PLOT.time2plot = PLOT.time; PLOT.time2plotDim = 'nd'; PLOT.timeConvert = 1; end
    
    DATA.Array{1,timeRow}       = PLOT.time2plot; %dimensionalise time array 
    
    minTime                     = min(PLOT.time); %[nd or s]
    maxTime                     = max(PLOT.time); %[nd or s]
    minTimeDim                  = minTime*PLOT.timeConvert; %[whatever]
    maxTimeDim                  = maxTime*PLOT.timeConvert; %[whatever]

    %  1       2   3     4      5   6      7   8    9    10   11        12      13      14      15   16
    %  istep time F_top F_bot Tmin Tmean Tmax Vmin Vrms Vmax eta_min eta_mean eta_max ra_eff Nu_top Nu_bot
    
    %  17       18   19     20    21      22        23      24              25          26       27
    %  C_min C_mean C_max F_mean F_max erupt_rate erupta erupt_heatflux entrainment Cmass_error H_int
    
    %% SET UP FIELD VARIABLES
    %  	1                 	2                   3                   4                   5                   6
    %  	data name           variable label      rprof.dat label    	dim. scale      	data dimension      individual range    
    FIELD_M = {
        'time steps'        'cumul. time steps' 'istep'          	1                   '#'                 false           %1
        'time'              'time'              'time'           	PLOT.timeConvert    PLOT.time2plotDim   false           %2
        'top heatflux'     	'F_{top}'           'F_top'             SETUP.HFscale      	'mW/m^2'            false           %3
        'bottom heatflux'  	'F_{bot}'           'F_bot'             SETUP.HFscale    	'mW/m^2'          	false           %4
        'min. temperature'  'T_{min}'           'Tmin'              SETUP.Tscale        'K'                 false           %5
        'temperature'       'T_{mean}'          'Tmean'             SETUP.Tscale        'K'                 true            %6
        'max. temperature'  'T_{max}'           'Tmax'              SETUP.Tscale        'K'                 false           %7
        'min. velocity'     'v_{min}'           'vmin'              SETUP.Vscale        'cm/a'              false           %8
        'velocity'          'v_{mean}'        	'vrms'              SETUP.Vscale        'cm/a'              true            %9
        'max. velocity'     'v_{max}'           'vmax'              SETUP.Vscale        'cm/a'              false           %10
        'min. viscosity'    '\eta_{min}'        'eta_min'         	SETUP.etascale    	'Pa s'              false           %11
        'viscosity'         '\eta_{mean}'       'eta_mean'        	SETUP.etascale     	'Pa s'              true            %12
        'max. viscosity'    '\eta_{max}'        'eta_max'         	SETUP.etascale    	'Pa s'              false           %13
        'Ra_{eff}'          'Ra_{eff}'          'ra_eff'           	1                   '-'                 false           %14
        'Nu_{top}'          'Nu_{top}'          'Nu_top'          	1                   '-'                 false           %15
        'Nu_{bot}'          'Nu_{bot}'          'Nu_bot'           	1                   '-'                 false           %16
        'min. composition' 	'C_{min}'           'C_min'             1                   '-'                 false           %17
        'composition'     	'C_{mean}'        	'C_mean'          	1                   '-'                 true            %18
        'max. composition' 	'C_{max}'          	'C_max'             1                   '-'                 false           %19
        'mean melt fraction' 'F_{mean}'       	'F_mean'           	1                   '-'                 false           %20
        'max. melt fraction' 'F_{max}'       	'F_max'             1                   '-'                 false           %21
        'eruption rate'     'UCvarepsilondot'  	'erupt_rate'      	SETUP.Vscale       	'cm/a'           	false           %22
        'erupta'            'erupta'            'erupta'          	SETUP.lengthscale 	'm'                 false           %23
        'eruption heatflux' 'hf_{erupt}'        'erupt_heatflux'   	SETUP.HFscale    	'mW/m^2'         	false           %24
        'entrainment'       'en'                'entrainment'      	1                   '-'                 false           %25
        'conserv. error'    'Cmass_{err}'       'Cmass_error'     	1                   '-'                 false           %26
        'internal heating'  'H_{int}'           'H_int'          	SETUP.Hscale        'W/kg'              false           %27
    };
    
    % UNICODE VARIABLES
    %use the following character sequence to add unicode variables:
    %UCvarepsilondot => char(941)
    %UCvarepsilon => char(949)
    FIELD_M(:,2) = strrep(FIELD_M(:,2),'UCvarepsilondot',{char(941)}); %does only work if string consists ONLY of unicode character
    FIELD_M(:,2) = strrep(FIELD_M(:,2),'UCvarepsilon',{char(949)}); %does only work if string consists ONLY of unicode character

    % FIELD VARIABLES ADJUSTMENTS
    if SWITCH.dimensional_input
        DATA.Array{1,14} = DATA.Array{1,14}.*SETUP.eta0.*SETUP.Ra0; %undo Ra_eff = Ra_0/eta_mean if dimensional mode
    end
    if SWITCH.dim || SWITCH.dimensional_input 
        %nothing to do
    else
        %adjust for non-dimensional parameters
        FIELD_M(:,4) = {1};
        FIELD_M(:,5) = {'nd'};
    end
    
    %% DISPLAY MODEL DETAILS II
    display(['Top-BC:            ',SETUP.topBC])
    display(['Time Range:        ',num2str(minTimeDim,3),' - ',num2str(maxTimeDim,3),' ',PLOT.time2plotDim])
    
    %% COLOURING ADJUSTMENTS
    if strcmp(STYLE.colorMode,'black'); line_color = 1-line_color; end
    
    %% PLOTTING
    num_subplot=0;
    for i_field=1:nr_plots
        %set parameter to plot
        numRow   = find(strcmp(DATA.title,DATA.string(i_field)));
        
        %dimensionalise data
        DATA.Array{1,numRow} = DATA.Array{1,numRow}*FIELD_M{numRow,4};
        if SWITCH.parameterRange && FIELD_M{numRow,6} %parameter range
            DATA.Array{1,numRow-1} = DATA.Array{1,numRow-1}*FIELD_M{numRow-1,4};
            DATA.Array{1,numRow+1} = DATA.Array{1,numRow+1}*FIELD_M{numRow+1,4};
        end
        
        %set subplot
        if nr_plots>1
            num_subplot=num_subplot+1;
            if nr_plots>4
                if mod(nr_plots,2)
                    hax = subplot((nr_plots+1)/2,2,num_subplot);
                else
                    hax = subplot(nr_plots/2,2,num_subplot);
                end
            else
                hax = subplot(nr_plots,1,num_subplot);
            end
        end
        hold on
        
        %performance plot
        if IN.plotPerformance && i_field==nr_plots
            dt = zeros(size(DATA.Array{1,timeRow},1),1);
            for i=1:size(DATA.Array{1,timeRow},1)
                if i==size(DATA.Array{1,timeRow},1)
                    dt(i,1) = DATA.Array{1,timeRow}(i,:)-DATA.Array{1,timeRow}(i-1,:);
                else
                    dt(i,1) = DATA.Array{1,timeRow}(i+1,:)-DATA.Array{1,timeRow}(i,:);
                end
            end
            pp1 = plot(DATA.Array{numRow}, dt,'Color',line_color);
            if strcmp(FIELD_M(numRow,5),'-') %xlabel
                dimString       = '';
            else
                dimString       = [' [',FIELD_M{numRow,5},']'];
            end
            if strcmp(FIELD_M(timeRow,5),'-') %ylabel
                dimStringTime 	= '';
            else
                dimStringTime 	= [' [',FIELD_M{timeRow,5},']'];
            end  
            xlabel(strcat('time step',dimString))
            ylabel(strcat('time step',dimStringTime))
            grid on
            if SWITCH.MinMaxLegend
                legend('^{dt}/_{time step}')
            end
            if i_field==nr_plots;
                h_runs(irun,1) = pp1;
            end
            break
        end
        
        %time plot
        if SWITCH.parameterRange && FIELD_M{numRow,6}
            colourMax = [0.81 0.33 0.2];
            colourMin = [0.4 0.64 0.18];
            pp2 = plot(DATA.Array{1,timeRow}, DATA.Array{numRow-1},'Color',colourMin); 	%minimum
            pp1 = plot(DATA.Array{1,timeRow}, DATA.Array{numRow},'Color',line_color);   %mean
            pp3 = plot(DATA.Array{1,timeRow}, DATA.Array{numRow+1},'Color',colourMax);	%maximum
            if SWITCH.MinMaxLegend
                legend([pp3,pp1,pp2],[FIELD_M(numRow+1,2),FIELD_M(numRow,2),FIELD_M(numRow-1,2)],'Location','Best');
            end
        else
            pp1 = plot(DATA.Array{1,timeRow}, DATA.Array{numRow},'Color',line_color);   %mean
            if SWITCH.MinMaxLegend
                legend(pp1,FIELD_M(numRow,2),'Location','Best');
            end
        end
        if i_field==nr_plots; 
            h_runs(irun,1) = pp1; 
        end
        
        %axes labelling
        if SWITCH.dim || SWITCH.dimensional_input
            if strcmp(FIELD_M(timeRow,5),'-') %xlabel
                dimStringTime 	= '';
            else
                dimStringTime 	= [' [',FIELD_M{timeRow,5},']'];
            end
            if strcmp(FIELD_M(numRow,5),'-') %ylabel
                dimString       = '';
            else
                dimString       = [' [',FIELD_M{numRow,5},']'];
            end
        else
            dimStringTime   = ' [nd]';
            dimString       = ' [nd]';
        end
        xlabel([FIELD_M{timeRow,1},dimStringTime])
        ylabel([FIELD_M{numRow,1},dimString])
        
        grid on
    end %loop
    IN.save_string = ([IN.save_string,FILE.name,'_']);
    display(' ')
end

%% LEGEND
if ~SWITCH.MinMaxLegend %not applied if individual legends are switched on
    hl = legend(h_runs, IN.fname_vector, 'Location', 'NorthEast', 'interpreter', 'none');
    % hl = legend(h_runs, IN.fname_vector, 'Location', 'SouthEast');
end

%% STYLE PLOT
if SWITCH.stylePlots
%     STYLE.Legend = false; %done later
    if SWITCH.styleLegend; STYLE.Legend = true; else STYLE.Legend = false; end
    f_figStyle(STYLE);
end
if SWITCH.styleBackground
    BACK.ApplyTo    = 'all';          %'current', 'all'
    BACK.colorMode  = STYLE.colorMode;
    f_background(BACK) %set plot background of each subplot
end
% if SWITCH.styleLegend && exist('hl','var')
%     %only works like this for the last subplot
%     STYLE.hLegend = hl;
%     STYLE.currentAxis = hax(end,1); %sometimes gca is not updated (Matlab bug!)
%     %axes(hax(end,1)) %sometimes gca is not updated (Matlab bug!)
%     f_legendStyle(STYLE);
% end

%% ANNOTATION
if SWITCH.annotation
%     pause(0.5);
    f_annotations(PLOT,STYLE);
end

%% SAVING PLOTS
if SAVE.Plot
    SAVE.Directory = strcat(folder_im,FILE.name,'/');
    if strcmp(STYLE.colorMode,'white')
        SAVE.blackBackground=0;
    elseif strcmp(STYLE.colorMode,'black')
        SAVE.blackBackground=1;
    end
    if strcmp(STYLE.colorMode,'black'); endix='_black'; else endix=''; end
%     SaveDirectory = [file_stem_im,fname,'/'];
    SAVE.FigureName = strcat(IN.save_string,endix);   %file name
    if SWITCH.dim
        SAVE.FigureName = strcat(SAVE.FigureName,'_DIM');
    end
    SAVE.FigureNr               = 1;
    SAVE.keepAspect             = true;
    SAVE.jpgResolution       	= '-r500';
    
    f_saveFig( SAVE )
end

%% FINISHING UP
display(' ')
display('                      FINISHED.')










