
%%                                            PARAMETER DIMENSIONALIZATION

%                                                            Dezember 2015

function [SETUP,SWITCH] = f_dimParameter(SWITCH,FILE)

%% STANDARD PARAMETERS
% MANUAL PARAMETERS (adjust here)
SETUP.D                 = 1;            %is later converted to dimensional value if in dimensional mode!
SETUP.secyear           = 3600*24*365.25;
SETUP.g                 = 9.81;         % [m/s2]
SETUP.deltaT            = 2500;       	% [K]
SETUP.tcond_dimensional = 3.0;          % th. conductivity [W/(m K)]
SETUP.rho0              = 3300;     	% reference density [kg/m3]
SETUP.cp_dimensional    = 1200.0;       % reference heat capacity [J/(kg K)]
SETUP.alpha             = 3e-5;         % th. expansivity [1/K]

% AUTOMATICALLY DETERMINE PARAMETERS (from refstat.dat if possible)
filestem = [FILE.directory,FILE.name,'_refstat.dat'];
if SWITCH.dimensional_input && exist(filestem,'file')
    % READ PARAMETERS FROM REFSTAT.DAT (if available)  THOSE ARE 1 IN NON-DIMENSIONAL MODE!!!!!
    GRID.nz = 0; %reads only first line of profile
    [PARA] = f_importData(FILE,GRID);
    SETUP.tcond_dimensional = PARA.Tcond(1,1); 	% th. conductivity [W/(m K)]
    SETUP.rho0              = PARA.rho(1,1);   	% reference density [kg/m3]
    SETUP.cp_dimensional    = PARA.Cp(1,1);    	% reference heat capacity [J/(kg K)]
    SETUP.alpha             = PARA.expan(1,1);	% th. expansivity [1/K]
%     SETUP.deltaT            = PARA.T_ref;     	% [K]   <<<<<<<<<<<<<<<<
end


%% SPECIFIC PARAMETERS
if SWITCH.parameter==1      %Standard *************************************
    SETUP.topBC         = 'free-slip';
    SETUP.Ra0        	= 1e6;
    SETUP.D_dim         = 2890e3;

elseif SWITCH.parameter==7      %Ra=1e7 *************************************
    SETUP.topBC         = 'free-slip';
    SETUP.Ra0        	= 1e7;
    SETUP.D_dim         = 2890e3;
    
elseif SWITCH.parameter==8      %Ra=1e8 *************************************
    SETUP.topBC         = 'free-slip';
    SETUP.Ra0        	= 1e8;
    SETUP.D_dim         = 2890e3;
    
elseif SWITCH.parameter==11 
    SETUP.topBC         = 'sticky-air';
    SETUP.Ra0        	= 1.1639e6;
    SETUP.D_dim         = 3040e3;
    SETUP.d_air         = 0.05;
    
elseif SWITCH.parameter==110  %old
    SETUP.topBC         = 'sticky-air';
    SETUP.Ra0        	= 1e6;
    SETUP.D_dim         = 2890e3;
    SETUP.d_air         = 0.05; 
    
elseif SWITCH.parameter==13  %thin air layer ******************************
    SETUP.topBC         = 'sticky-air';
    SETUP.Ra0         	= 8.6533e6;
    SETUP.D_dim         = 3000e3;
    SETUP.d_air         = 0.05;
    
elseif SWITCH.parameter==4  %Solomatov 2004 *******************************
    SETUP.topBC         = 'free-slip';
    SETUP.Ra0           = 0.1;
    SETUP.D_dim         = 600e3;
    
elseif SWITCH.parameter==14
    SETUP.topBC         = 'sticky-air';
    SETUP.Ra0         	= 0.11664;
    SETUP.D_dim         = 631.5789e3;
    SETUP.d_air         = 0.05;  
        
elseif SWITCH.parameter==114 %old
    SETUP.topBC         = 'sticky-air';
    SETUP.Ra0         	= 0.1;
    SETUP.D_dim         = 600e3;
    SETUP.d_air         = 0.05;  
    
elseif SWITCH.parameter==17  %Ra=1e7 sticky-air ***************************
    SETUP.topBC         = 'sticky-air';
    SETUP.Ra0         	= 1.e7;
    SETUP.D_dim         = 3040e3; 
    SETUP.d_air         = 0.05;
    
elseif SWITCH.parameter==18  %Ra=1e8 sticky-air ***************************
    SETUP.topBC         = 'sticky-air';
    SETUP.Ra0         	= 1.e8;
    SETUP.D_dim         = 3040e3;
    SETUP.d_air         = 0.05;
    
elseif SWITCH.parameter==19	%Special Lab *************************************
    SETUP.topBC         = 'free-slip';
    SETUP.D_dim         = 0.265; %2890e3;
    SETUP.rho0              = 1439;     	% reference density in kg/m3
%     SETUP.rho0              = 388.7339;  %105.0132; %3.8873 %Ra1e5
%     SETUP.rho0              = 869.2354;  %Ra5e5
%     SETUP.rho0              = 1.2293e3;  %1050.132; %3.8873e1 %Ra1e6
%     SETUP.rho0              = 2.7488e3;  %Ra5e6
%     SETUP.rho0              = 3.8873e3;  %10501.32; %3.8873e2 %Ra1e7
%     SETUP.rho0              = 8.6924e3;  %Ra5e7
%     SETUP.rho0              = 1.2293e4;  %105013.2; %3.8873e3 %Ra1e8

    T_heater            = 80.15;
    SETUP.tcond_dimensional = 0.34;
%     T_heater            = 25.9685; %deta=1.1
%     SETUP.tcond_dimensional = 0.0048;
%     T_heater            = 30.9324; %deta=1.1
%     SETUP.tcond_dimensional = 0.0355;
%     T_heater            = 39.0967; %deta=5
%     SETUP.tcond_dimensional = 0.086;
%     T_heater            = 45.8315; %deta=10
%     SETUP.tcond_dimensional = 0.1277;
%     T_heater            = 64.2944; %deta=50
%     SETUP.tcond_dimensional = 0.2419;
%     T_heater            = 74.2838; %deta=100
%     SETUP.tcond_dimensional = 0.3037;
%     T_heater            = 121.7815; %deta=490
%     SETUP.tcond_dimensional = 0.5976; 

    T_ambient               = 25.2;
    T0                      = 25.2;
    SETUP.deltaT            = T_heater-T_ambient; %54.95; %already dimensional      	% in K
    SETUP.alpha             = 3.1e-4;
    SETUP.cp_dimensional    = 2280.0;       % reference heat capacity in J/kg/K
    SETUP.kappa         = SETUP.tcond_dimensional/(SETUP.rho0*SETUP.cp_dimensional);
    eta0_in             = 1080*exp(-0.156*T0+6.25e-4*T0^2); %32.3;
%     eta0_in             = 31.5135; %isoviscous

    SETUP.Ra0        	= (SETUP.rho0*SETUP.g*SETUP.alpha*SETUP.deltaT*SETUP.D_dim^3)/(SETUP.kappa*eta0_in);
    
elseif SWITCH.parameter==20	%Special Lab 2 *************************************
    SETUP.topBC         = 'free-slip';
    SETUP.D_dim         = 0.265; %2890e3;
    SETUP.rho0              = 1439;     	% reference density in kg/m3
%     SETUP.rho0              = 388.7339;  %105.0132; %3.8873 %Ra1e5
%     SETUP.rho0              = 869.2354;  %Ra5e5
%     SETUP.rho0              = 1.2293e3;  %1050.132; %3.8873e1 %Ra1e6
%     SETUP.rho0              = 2.7488e3;  %Ra5e6
%     SETUP.rho0              = 3.8873e3;  %10501.32; %3.8873e2 %Ra1e7
%     SETUP.rho0              = 8.6924e3;  %Ra5e7
%     SETUP.rho0              = 1.2293e4;  %105013.2; %3.8873e3 %Ra1e8

    T_heater            = 80.15;
    SETUP.tcond_dimensional = 0.34e-6;
%     T_heater            = 25.9685; %deta=1.1
%     SETUP.tcond_dimensional = 0.0048;
%     T_heater            = 30.9324; %deta=1.1
%     SETUP.tcond_dimensional = 0.0355;
%     T_heater            = 39.0967; %deta=5
%     SETUP.tcond_dimensional = 0.086;
%     T_heater            = 45.8315; %deta=10
%     SETUP.tcond_dimensional = 0.1277;
%     T_heater            = 64.2944; %deta=50
%     SETUP.tcond_dimensional = 0.2419;
%     T_heater            = 74.2838; %deta=100
%     SETUP.tcond_dimensional = 0.3037;
%     T_heater            = 121.7815; %deta=490
%     SETUP.tcond_dimensional = 0.5976; 

    T_ambient               = 25.2;
    T0                      = 25.2;
    SETUP.deltaT            = T_heater-T_ambient; %54.95; %already dimensional      	% in K
    SETUP.alpha             = 3.1e-10;
    SETUP.cp_dimensional    = 2280.0;       % reference heat capacity in J/kg/K
    SETUP.kappa         = SETUP.tcond_dimensional/(SETUP.rho0*SETUP.cp_dimensional);
    eta0_in             = 1080*exp(-0.156*T0+6.25e-4*T0^2); %32.3;
%     eta0_in             = 31.5135; %isoviscous

    SETUP.Ra0        	= (SETUP.rho0*SETUP.g*SETUP.alpha*SETUP.deltaT*SETUP.D_dim^3)/(SETUP.kappa*eta0_in);
    
else  % *******************************************************************
    error(['SWITCH.parameter = ',num2str(SWITCH.parameter),' not found!'])
end



%% ADDITIONAL SPECIFIC PARAMETER SUITES
if strcmp(SWITCH.parameterSuite,'standard')
    display('Parameter Suite:   STANDARD')

elseif strcmp(SWITCH.parameterSuite,'topo_bm')
    SETUP.D_dim             = 775e3;        % 850e3;	 % Depth in meters !!!
    SETUP.Ra0               = 1.5361;       % 2.0266
    
    SETUP.d_air             = 0.096774;     %just to define it...
    SETUP.g                 = 10;
    SETUP.tcond_dimensional = 3.3;
    SETUP.cp_dimensional    = 1000.0;
    SETUP.alpha             = 1e-5;
    SETUP.deltaT            = 0.01;         % in K
    display('Parameter suite:   TOPO BENCHMARK')

elseif strcmp(SWITCH.parameterSuite,'solomatov2004')
%     H_dummy = 6.3131e-12;
%     SETUP.Tscale            = SETUP.rho0*H_dummy*SETUP.D_dim^2/SETUP.tcond_dimensional;     %2500;         % in K
    SETUP.deltaT            = 2500;
    display('Parameter Suite:   SOLOMATOV 2004')
        
else
    error(['SWITCH.parameterSuite = ',SWITCH.parameterSuite,' not found!'])
end


%% CALCULATING ADDITIONAL PARAMETERS
if SWITCH.dim || SWITCH.dimensional_input
    SETUP.D = SETUP.D*SETUP.D_dim;
end
SETUP.kappa         = SETUP.tcond_dimensional/(SETUP.rho0*SETUP.cp_dimensional); % reference thermal diffusivity in m2/s
SETUP.eta0          = (SETUP.rho0*SETUP.g*SETUP.alpha*SETUP.deltaT*SETUP.D^3) / (SETUP.kappa*SETUP.Ra0);  % reference viscosity (varies with Ra0)
SETUP.v0            = SETUP.kappa/SETUP.D_dim * SETUP.secyear * 100;                    % in [cm/a]

%% CALCULATING PARAMETER SCALES
SETUP.lengthscale   = SETUP.D;                                                          % [m]
SETUP.timescale     = SETUP.D_dim^2/SETUP.kappa;                                        % [s]
SETUP.stressscale	= SETUP.eta0*SETUP.kappa/SETUP.D_dim^2 / 1e6;                       % stress scale in [MPa]
SETUP.edotscale  	= SETUP.kappa/SETUP.D_dim^2;                                        % strain-rate scale in [1/s]
%     dimstring_edot='s^{-1}';
%     edotscale_1e10 = edotscale*1e10;                                                  % strain rate in [1/s*1e10]
%     if ~IN.edot_log; edotscale=edotscale_1e10; dimstring_edot='10^{10}s^{-1}'; end
SETUP.Tscale        = SETUP.deltaT;                                                     % in [K]
SETUP.etascale      = SETUP.eta0;                                                       % in [Pa s]
SETUP.Pscale        = SETUP.stressscale/1e3;                                            % in [GPa]
SETUP.Hscale        = (SETUP.kappa*SETUP.cp_dimensional*SETUP.Tscale)/SETUP.D_dim^2;    % in [W/kg]
SETUP.HRscale       = SETUP.deltaT/SETUP.D_dim^2/SETUP.kappa;                           % in [K/s]
%XXXXX
SETUP.HFscale       = (SETUP.tcond_dimensional*SETUP.Tscale)/SETUP.D_dim /1e6;          % in [mW/m2]
%XXXXX
SETUP.Vscale        = SETUP.v0;                                                         % in [cm/a]
SETUP.rhoscale     	= SETUP.rho0;                                                       % in [kg/m3]

%% ADJUSTING VALUES
if strcmp(SETUP.topBC,'free-slip') %for free-slip cases
    SETUP.d_air         = 0.0;      %non-dimensional
    SETUP.d_air_dim     = 0.0;      %dimensional [m]
else %for sticky-air cases
    if ~isfield(SETUP,'d_air_dim'); SETUP.d_air_dim = SETUP.d_air*SETUP.D_dim; end %dimensional [m]
end

%NON-DIMENSIONAL CASE
if ~SWITCH.dim %adjust for non-dimensional mode
    SETUP.etascale    	= 1;                                                            % [nd]
    SETUP.lengthscale 	= 1;                                                            % [nd]
    SETUP.timescale     = 1;                                                            % [nd]
    SETUP.stressscale	= 1;                                                            % [nd]
    SETUP.edotscale  	= 1;                                                            % [nd]
    SETUP.Pscale        = 1;                                                            % [nd]
    SETUP.Hscale        = 1;                                                            % [nd]
    SETUP.HRscale       = 1;                                                            % [nd]
    SETUP.HFscale       = 1;                                                            % [nd]
    SETUP.Vscale        = 1;                                                            % [nd]
    SETUP.Tscale        = 1;                                                            % [nd]
    SETUP.rhoscale     	= 1;                                                            % [nd]
end

%DIMENSIONAL INPUT
if SWITCH.dimensional_input
    SETUP.d_air         = SETUP.d_air_dim;
    SETUP.etascale     	= 1;                                                            % [Pa s]
    SETUP.lengthscale 	= 1;                                                            % [m]
    SETUP.timescale     = 1;                                                            % [s]
    SETUP.stressscale	= 1/1e6;                                                        % [MPa]
    SETUP.edotscale  	= 1;                                                            % [1/s]
    SETUP.Pscale        = 1/1e9;                                                        % [GPa]
    SETUP.Hscale        = 1;                                                            % [W/kg]
    SETUP.HRscale     	= 1;                                                            % [K/s]
    %XXXXXX
    SETUP.HFscale       = 1/1e6;                                                        % [mW/m2]
    %XXXXXX
    SETUP.Vscale        = SETUP.secyear*100;                                         	% [cm/a]
    SETUP.Tscale        = 1;                                                            % [K]
    SETUP.rhoscale     	= 1;                                                            % [kg/m3]
end

%% PRINT INFORMATION
if SWITCH.dim || SWITCH.dimensional_input
    display(['D:                 ',num2str(SETUP.D/1e3),' km'])
else
    display(['D:                 ',num2str(SETUP.D)])
end
display(['Ra0:               ',num2str(SETUP.Ra0,3)])

end



