
%%   PLOT isoline topography

% Fabio Crameri, January 2014

%% NOTES
% make deriving lithosphere thickness (i.e., finding appropriate T value) automatically .....
% only works for temperature isoline, sofar
% add fill area for the top part.......

function [topo2d,PLOT,SAVE] = f_plotIsoline(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE)

lineWIDTH0      = STYLE.keyLineWidth;
normalise2mean  = logical(1);
    
%% READ TEMPERATURE ---------------------------------------------------
% Read temperature field information
[~, ~, ~, ~,T_3D,time, ~]     = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'temperature', SWITCH.Precision);
if PLOT.YZ_2Dcartesian; %exchange x and y
    dummy_3D = zeros(size(T_3D,2),size(T_3D,1),size(T_3D,3));
    dummy_3D(:,1,:)     = T_3D(1,:,:); T_3D = dummy_3D;
end
x2d(:,:,:)	= GRID.X_3D(:,:,:);   %in [m]
y2d(:,:,:) 	= GRID.Y_3D(:,:,:);   %in [m]
z2d(:,:,:) 	= GRID.Z_3D(:,:,:);   %in [m]

%--------------------------------
%% CHECK
if strcmp(GRID.Dim,'3-D')
    error('3-D plate isoline topography plot not implemented yet!')
end
%--------------------------------

%% DIMENSIONALIZATION
T_3D        = T_3D * SETUP.Tscale; %[K]
x2d         = x2d/1e3;    %in [km]
y2d         = y2d/1e3;    %in [km]
z2d         = z2d/1e3;    %depth in [km]

%% CRITICAL VALUES to define isoline
LITHO.Tisovalue = PLOT.lithoThickness(1,1);  %Temperature isovalue
LITHO.zmax = PLOT.lithoThickness(1,2); %depth in [km]

[LITHO] = f_lithoThickness(T_3D,z2d,LITHO); % derive lithosphere thickness by T contour:

%% NORMALISE THE VALUES TO THE MEAN
if normalise2mean
    topo2d = -LITHO.thickness + mean(LITHO.thickness(:));
else
    topo2d = LITHO.thickness;
end

nloopComp = 1;
if SWITCH.plotDifference
    if ~isfield(PLOT,'istopo2d_A') %for odd cases/snapshots
        PLOT.istopo2d_A = topo2d;
        return  %end execution of function here
    else
        if strcmp(TOPO.difference,'diff')
            topo2d_diff = PLOT.istopo2d_A - topo2d;
            topo2d = topo2d_diff;
            clearvars topo2d_diff
            PLOT = rmfield(PLOT,'istopo2d_A');
        elseif strcmp(TOPO.difference,'comp')
            nloopComp = 2;
        else
            error(['TOPO.difference = ',TOPO.difference,' not available!'])
        end
    end
end

for iloopComp = 1:nloopComp
    if SWITCH.plotDifference && strcmp(TOPO.difference,'comp')
        if iloopComp==1
            PLOT.istopo2d_B = topo2d;
            topo2d = PLOT.istopo2d_A;
        else
            topo2d = PLOT.istopo2d_B;
        end
    end
    topo_smooth_2 = zeros(size(topo2d));
    topo_smooth_1 = topo2d;

    if strcmp(GRID.Dim,'2-D')   % 2-D
        %------------------------
        % SMOOTHING 2-D
        %------------------------
        for jj=1:2
            topo_smooth_2(:,1) = smooth(topo_smooth_1(:,1),5,'moving');
            topo_smooth_1 = topo_smooth_2;
        end
        topo_smooth = topo_smooth_2;
        %------------------------

    elseif strcmp(GRID.Dim,'3-D') %3-D
        if TOPO.ascii
            z = topo2d(:,1); %cmb topo
            low = min(x); high = max(x); tix = low:0.01:high;
            low = min(y); high = max(y); tiy = low:0.01:high;
            [xi,yi] = meshgrid(tix,tiy);
            zi = griddata(x,y,z,xi,yi);
        else
            xi = y2d;
            yi = x2d;
            zi = topo2d(:,:,1); %cmb topo
        end
    end
    
    
    %% PLOT ISOLINE TOPOGRAPHY ---------------------------------------------------
    %% COUNT SUBPLOTS
    if iloopComp==1
        PLOT.nr_subplot = PLOT.nr_subplot+1;
        nr_subplot = PLOT.nr_subplot;
    end
    
    %% TITLE STRING & TIME
    if SWITCH.dim || SWITCH.dimensional_input
        if SWITCH.dimensional_input; time_dim=time; else time_dim=time*(SETUP.D_dim^2/SETUP.kappa); end  % get dimensional time [s]  %NEED TO CHANGE THAT !!!
        fieldString1 = 'IS topography @ ';
        if PLOT.titleOnlyTime; fieldString1 = ''; end
        if time_dim/SETUP.secyear/1e6>100
            title_plot  = [fieldString1,num2str(time_dim/SETUP.secyear/1e9,3),' Ga'];
        elseif time_dim/SETUP.secyear/1e6<0.0001
            title_plot  = [fieldString1,num2str(time_dim/SETUP.secyear,3),' a'];
        elseif time_dim/SETUP.secyear/1e6<0.1
            title_plot  = [fieldString1,num2str(time_dim/SETUP.secyear/1e3,3),' ka'];
        else
            title_plot  = [fieldString1,num2str(time_dim/SETUP.secyear/1e6,3),' Ma'];
        end
    else
        title_plot  = [fieldString1,num2str(time,3),' '];
    end
    if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
    
    %% FIGURE...
    figure(1)
    
    %% SUBPLOT LAYOUT...
    if iloopComp==1;
        if isfield(PLOT,'subplotLayout') %manual arrangement
            sub_current=[PLOT.subplotLayout(1,1),PLOT.subplotLayout(1,2),nr_subplot];
        else
            if PLOT.nrPlots>=4
                if mod(PLOT.nrPlots,2)
                    sub_current=[(PLOT.nrPlots+1)/2 2 nr_subplot];
                else
                    sub_current=[PLOT.nrPlots/2 2 nr_subplot];
                end
            else
                sub_current=[PLOT.nrPlots 1 nr_subplot];
            end
        end
        if PLOT.reverseLayout %top-down plotting
            if ~isfield(PLOT,'layoutNum')
                PLOT.layoutNum = zeros(sub_current(1,1),sub_current(1,2));
                idx = 0;
                for ii=1:size(PLOT.layoutNum,1)
                    for jj=1:size(PLOT.layoutNum,2)
                        idx = idx+1;
                        PLOT.layoutNum(ii,jj) = idx;
                    end
                end
                idx = 0; PLOT.layoutNumTransposed = PLOT.layoutNum;
                for jj=1:size(PLOT.layoutNum,2)
                    for ii=1:size(PLOT.layoutNum,1)
                        idx = idx+1;
                        PLOT.layoutNumTransposed(ii,jj) = idx; %transposed layout
                    end
                end
            end
            %UPDATE TO NEW LAYOUT
            %       while PLOT.nr_subplot is still setup the old way!
            nr_subplot = PLOT.layoutNum(PLOT.layoutNumTransposed==nr_subplot);
            sub_current(1,3) = nr_subplot;
        end
        %% SUBPLOT
        subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3));
        %% CURRENT AXIS
        AXcurrent = gca; %save current axes handle
    end
    
    %% SETUP PLOTTING VARIABLES
    if strcmp(GRID.Dim,'2-D')   % 2-D
        x_PLOT          = x2d(:,1);
        topo_PLOT       = topo2d;
        
        if iloopComp==1;
            topoCOLOUR0 = STYLE.keyLineColor;
            topoCOLOUR  = STYLE.keyLineColor;
            topoOPACITY = 0.7;
        else
            topoCOLOUR0 = [0.7 0.2 0.2];
            topoCOLOUR  = [0.7 0.2 0.2];
            topoOPACITY = 0.4;
        end
        
        %% PLOTTING TOPOGRAPHY ----------------------------------------------
        i_start=1; i_end=1;  %NO SMOOTHING IMPLEMENTED YET....
%         if SWITCH.plotTOPOtrue; i_start=1; else i_start=2; end
%         if SWITCH.plotTOPOsmooth; i_end=2; else i_end=1; end
        
        %plot topo
        for i_topo=i_start:i_end
            if i_topo==1 %plot true topo
                topo2plot   = topo_PLOT;
                color2plot  = topoCOLOUR0;
            elseif i_topo==2 %plot smooth topo
                topo2plot   = topoSmooth_PLOT;
                color2plot  = topoCOLOUR;
            end
            
            %         if TOPO.water && ~strcmp(TOPO.areaFill,'updown') %add water layer
            %             colorWater = [0 0.5 1]; alphaWater = 0.2;
            %             if strcmp(PLOT.color_definition,'black');
            %                 colorWater = [0 0.5 1]; alphaWater = 0.7;
            %             end
            %             topoNegative = topo2plot';
            %             topoNegative(topo2plot>=0) = NaN; %remove positive topo values
            %             if max(isnan(topoNegative))==1 %if there are NaNs
            %                 %seperate the two lines
            %                 NanLocations = find(isnan(topoNegative));
            %                 NanLocations = [0 NanLocations size(topoNegative,2)+1]; %add start and end point
            %                 nLineSegment = size(NanLocations,2)-1;
            %                 for iLineSegment=1:nLineSegment
            %                     startLoc = NanLocations(1,iLineSegment) +1;
            %                     endLoc = NanLocations(1,iLineSegment+1) -1;
            %                     if endLoc<=startLoc+1; continue; end %skip this one: no line in between
            %
            %                     S_xpoints = x_PLOT(startLoc:endLoc,1)';
            %                     S_upper = topoNegative(1,startLoc:endLoc);
            %                     S_lower = zeros(size(S_upper));
            %
            %                     fill([min(S_xpoints); S_xpoints'; max(S_xpoints)],[min(S_lower); S_upper'; min(S_lower)],...
            %                         colorWater,'EdgeColor','none','FaceAlpha',alphaWater);
            %                     hold on
            %                 end
            %             end
            %         end
            
            PLOT.TOPOhLine = plot(x_PLOT,topo2plot,'Color',color2plot,'LineWidth',lineWIDTH0);
            hold on
            
            %         if ~strcmp(TOPO.areaFill,'none')
            %             xpoints = x_PLOT;
            %             upper = topo2plot;
            %             if strcmp(TOPO.areaFill,'down')
            %                 color = color2plot;
            %                 lower = zeros(size(upper))+(min(upper)-1/10*(max(upper)-min(upper)));
            %                 if TOPO.both; PLOT.topoLOWval = lower(1,1); lower = zeros(size(upper))-50; end %set very low to be deeper than dynamic topo low
            %                 if SWITCH.Colorbar(1,2); lower = zeros(size(upper))+FIELD.cColorbarMIN; end %constant axis min/max
            %                 if SWITCH.plotDifference && strcmp(TOPO.difference,'diff'); lower = lower*0; end %in relation to 0 topography
            %
            %             elseif strcmp(TOPO.areaFill,'updown')
            %                 color = color2plot;
            %                 lower = zeros(size(upper));
            %             else
            %                 error(['TOPO.areaFill mode ',TOPO.areaFill,'not recognised!'])
            %             end
            %
            %             PLOT.isTOPOhArea(iloopComp,1) = fill([min(xpoints); xpoints; max(xpoints)],[min(lower); upper; min(lower)],color,'EdgeColor','none','FaceAlpha',topoOPACITY);
            %         end
        end
        
        %------------------------------------------------------------------
        %% ANNOTATIONS
        if iloopComp==1;
            if SWITCH.dim || SWITCH.dimensional_input
                xlabel('width [km]')
                ylabel('topography [km]')
            else
                plot(x2d(:,1),topo2d,'Color',[0.039216 0.14118 0.41569]);
                %             if SWITCH.plotTOPOtrue; plot(x2d(:,1),topo2d,'Color',[0.039216 0.14118 0.41569]); end
                %             if SWITCH.plotTOPOsmooth; hold on; plot(x2d(:,1),topo_smooth,'Color',[0.4 0 0]); end  %smooth
                xlabel('width [-]')
                ylabel('topography [-]')
            end
            if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
            if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
                htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
            else
                htitle = title(title_plot); %centered
            end
            if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.nr_subplot,:)); end
            
            axis tight
            if ~normalise2mean; axis ij; end
            %  DOESN'T WORK HERE ?????? FOR SOME REASON.........:
            if SWITCH.Colorbar(1,2); ylim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
            if SWITCH.setAxisLimit
                if size(SWITCH.axisLimit,1)>1  %more than one axis-zoom value
                    xlim(SWITCH.axisLimit(PLOT.loop_case,1:2));
                else
                    xlim(SWITCH.axisLimit(1,1:2));
                end
            end
            %                 set(AXcurrent,'YGrid','on') %only horizontal grid
            grid on
            box on
            %set tickmarks out- or inside
            set(gca,'TickDir',SWITCH.tickDir)
            
            if SWITCH.texting
                text(min(xlim),max(ylim),['min val: ',num2str(min(topo2d(:)),2),'   (',num2str(min(topo2d(:)),2),')'],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
                text(max(xlim),max(ylim),['max val: ',num2str(max(topo2d(:)),2),'   (',num2str(max(topo2d(:)),2),')'],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
                display(['   max.topo: ',num2str(max(topo2d)),' / min.topo: ',num2str(min(topo2d))])
                %                 % ...and smooth
                %                 %                 text(min(xlim),max(ylim),['min val: ',num2str(min(topo_smooth(:)),2)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
                %                 %                 text(max(xlim),max(ylim),['max val: ',num2str(max(topo_smooth(:)),2)],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
                %                 display(['   max.topo_smooth: ',num2str(max(topo_smooth)),' / min.topo_smooth: ',num2str(min(topo_smooth))])
            end
            
            if SWITCH.plotDifference && iloopComp==nloopComp %only for difference plot
                if isfield(PLOT,'titleString')
                    legend(PLOT.isTOPOhArea,PLOT.titleString{1,:},'Location','southeast','Interpreter','none') %area
                else
                    legend(PLOT.isTOPOhArea,SWITCH.fname_vector,'Location','southeast','Interpreter','none') %area
                end
            end
        end
        
    elseif strcmp(GRID.Dim,'3-D') %NOT IMPLEMENTED YET!!!!
        %% 3-D
        if SWITCH.plotTOPOtrue && SWITCH.plotTOPOsmooth
            n_start     = 1;
            n_end       = 2;
        elseif SWITCH.plotTOPOtrue
            n_start     = 1;
            n_end       = 1;
        elseif SWITCH.plotTOPOsmooth
            n_start     = 2;
            n_end       = 2;
        end
        
        varScale2 = TOPO.varScale;
        %             if SWITCH.dim || SWITCH.dimensional_input; varScale2 = FIELD.varScale; else varScale2 = 1; end
        
        for i_field=n_start:n_end
            if SWITCH.plotTOPOtrue && SWITCH.plotTOPOsmooth
                subplot(2,1,i_field)
            end
            xi_plot = xi*varScale2; %[km]
            yi_plot = yi*varScale2; %[km]
            zi_plot = zi*varScale2; %[km]
            if i_field==2 %plot topo smooth
                %------------------------
                % SMOOTHING 3-D
                %------------------------
                F = [.05 .1 .05; .1 .4 .1; .05 .1 .05];
                for jj=1:20 %smoothing
                    ZC = conv2(zi_plot,F,'same');
                    zi_plot=ZC;
                end
                %------------------------
            end
            
            surf(xi_plot,yi_plot,zi_plot,'EdgeColor','none')
            % contour(xi,yi,zi)
            if ~normalise2mean; axis ij; end
            axis tight
            box on
            title(title_plot) %TITLE
            if SWITCH.dim || SWITCH.dimensional_input
                xlabel('y-width [km]')
                ylabel('x-width [km]')
                zlabel('topography [km]')
            else
                xlabel('y-width')
                ylabel('x-width')
                zlabel('topography')
            end
        end
        if SWITCH.Colorbar(1,2); zlim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
        clearvars low high tix tiy
    end %3-D
    
    if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else nr_hax = 1; end
    %for function output:
    PLOT.hax(nr_hax,1)  = AXcurrent;
    
    %% SET ASPECT RATIO ==================================
    if strcmp(GRID.Dim,'2-D')
        aspect_ratio(1) = max(x_PLOT)/SETUP.D;
        if SWITCH.dim || SWITCH.dimensional_input; aspect_ratio(1) = aspect_ratio(1)*1e3; end
        if SWITCH.dimensional_input; aspect_ratio(1) = max(x_PLOT)/(SETUP.D_dim/1e3); end
        if SWITCH.setAxisLimit;  aspect_ratio(1) = (SWITCH.axisLimit(1,2)-SWITCH.axisLimit(1,1))/(SWITCH.axisLimit(1,4)-SWITCH.axisLimit(1,3)); end %if manual axis extent
        aspect_ratio(2) = 1;
    elseif strcmp(GRID.Dim,'3-D')
        aspect_ratio(1) = GRID.ny/GRID.nz;
        aspect_ratio(2) = GRID.nx/GRID.nz;
    end
    
    %% FIGURE SIZE & POSITION ==================================
    figure(1)
    hold on
    
    %% COLORBAR ==================================
    colorbar;   %define dummy colorbar
    cb = NaN; 	%this is a flag if no colorbar is used
    
    if strcmp(GRID.Dim,'3-D')
        %% SPECIFY COLORMAP FOR CURRENT AXES
        AXhandles(1) = AXcurrent;  %big plot axis handle
        if exist('haxZ','var');
            AXhandles(2) = haxZ; %zoom plot axis handle
            loop_zoom = 2;
        else
            loop_zoom = 1;
        end
        PLOT.cb      = cb;      % colorbar handle
        for izoom=1:loop_zoom
            if ~PLOT.multipleColormap && izoom>1; continue; end
            PLOT.hax = AXhandles(izoom);
            [SWITCH] = f_colormap(SWITCH,PLOT);
        end
    end
    
    %% SIMPLIFY FIGURE ==================================
    if SWITCH.simplify
        %SET AXES ASPECT RATIO ----
        XaxisAR = aspect_ratio(1);
        YaxisAR = aspect_ratio(2);
        ZaxisAR = 1;
        set(gca,'PlotBoxAspectRatio',[XaxisAR YaxisAR ZaxisAR])
        %--------------------------
        
        %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
        PLOT.spcurrent          = sub_current;
        PLOT.sp_chax            = AXcurrent;
        if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else PLOT.sp_chaxz = NaN; end
        PLOT.sp_ccb             = cb;   %colorbar handle
        PLOT.title              = title_plot;  	%title string
        
        [PLOT] = f_splayout(SWITCH,PLOT,GRID,FIELD);
    end
end

%% FUNCTION OUTPUT
%indicate axis handle as graph subplot
SAVE.graphPlotHandles = [SAVE.graphPlotHandles; AXcurrent]; %indicate axis handle as graph subplot
SAVE.PlotHandles = [SAVE.PlotHandles; AXcurrent];





