
%%   PLOT horizontal PLATE VELOCITY

% Fabio Crameri, November 2014

%% NOTES
% CHECK AGAIN CAREFULLY (LITHOthickness and grid dimensions/labels).......
% make deriving lithosphere thickness (i.e., finding appropriate T value) automatically .....

function [vh_plate,PLOT,SAVE] = f_plotPlateVel(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE)

%% INPUT
lineCOLOUR0 = STYLE.keyLineColor; %Color line h. plate velocity
lineWIDTH0  = STYLE.keyLineWidth;

%% READ TEMPERATURE ---------------------------------------------------
% Read temperature field information
[~, ~, ~, ~,T_3D, ~, ~]     = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'temperature', SWITCH.Precision);
if PLOT.YZ_2Dcartesian || size(T_3D,1)==1; %exchange x and y
    dummy_3D = zeros(size(T_3D,2),size(T_3D,1),size(T_3D,3));
    dummy_3D(:,1,:)     = T_3D(1,:,:); T_3D = dummy_3D;
end

%% READ HORIZONTAL VELOCITY ---------------------------------------------------
% Read horizontal velocity information
if strcmp(GRID.Dim,'2-D')   % in 2-D this is the horizontal velocity
    [~,~,~,~,VX_3D,VY_3D,VZ_3D,~,~,~]    = f_ReadStagYY(FILE.directory, FILE.name, FILE.number, 'velocity', SWITCH.Precision);
    if PLOT.YZ_2Dcartesian || size(VX_3D,1)==1; %exchange x and y
        dummy_3D = zeros(size(VX_3D,2),size(VX_3D,1),size(VX_3D,3));
        dummy_3D(:,1,:)     = VX_3D(1,:,:); VX_3D = dummy_3D;
        dummy_3D(:,1,:)     = VY_3D(1,:,:); VY_3D = dummy_3D;
        dummy_3D(:,1,:)     = VZ_3D(1,:,:); VZ_3D = dummy_3D;
    end
    if strcmp(GRID.Type,'cylindrical')
        if max(VX_3D(:))==0 %exchange x and y
            dummy_3D = VX_3D;
            VX_3D = VY_3D; VY_3D = dummy_3D;
        elseif max(VX_3D(:))~=0 && max(VY_3D(:))==0
        else
            error('both VX_3D and VY_3D appear to be zero: check here!')
        end
    end
    VH_3D = VX_3D;  %%% DEFINE HORIZONTAL VELOCITY
else
    error('3-D plate velocity plot not implemented yet!');
end
x2d(:,:,:)	= GRID.X_3Dp(:,:,:);   %in GRID.Xdim
y2d(:,:,:) 	= GRID.Y_3Dp(:,:,:);   %in [whatever]
z2d(:,:,:) 	= GRID.Z_3Dp(:,:,:);   %in [whatever]

%--------------------------------
%% CHECK
% this needs actual depth switched on
if SWITCH.actualDepth || strcmp(SETUP.topBC,'free-slip') %nothing to be done
else
    error('this needs actual depth switched on!')
end
%--------------------------------
if strcmp(GRID.Type,'cylindrical')
    % RE-FLIP DEPTH VECTOR AND ACCOUNT FOR STICKY-AIR LAYER
    z2d = z2d +SETUP.d_air*GRID.dimFactor;  %set z=0 to real surface
    z2d = 1*GRID.dimFactor -z2d; % reverse z-axis  (1.)
end

%% DIMENSIONALIZATION
VH_3D       = VH_3D * SETUP.Vscale;  %[nd]->[cm/a]
T_3D        = T_3D * SETUP.deltaT; %[K]


%% CRITICAL VALUES to define lithosphere core
% LITHO.Tisovalue = PLOT.lithoThickness(1,1) /2;  %Temperature isovalue
% LITHO.zmax = PLOT.lithoThickness(1,2) /2; %depth in [km]
LITHO.Tisovalue = 700; %[K]; for lithosphere definition
LITHO.zmax      = 150;  %[km]; for lithosphere definition
LITHO.zmin      = 5;  %[km]; for lithosphere definition
LITHO.gridpoints= 0; %just to define it as it is used here
if SWITCH.dim || SWITCH.dimensional_input
    z2dx = GRID.Z_3D/1e3; %[km]
    if ~strcmp(GRID.Xdim,'km'); warning(['f_lithoThickness input should be in [',GRID.Xdim,']!']); end
else
    z2dx = GRID.Z_3Dp; %[nd]
    LITHO.zmax      = LITHO.zmax *1e3/SETUP.D_dim; %from [km] to [nd]
    LITHO.zmin      = LITHO.zmin *1e3/SETUP.D_dim; %from [km] to [nd]
end
[LITHO] = f_lithoThickness(T_3D,z2dx,LITHO); % derive lithosphere thickness by T contour:

%% PROBLEM CHECK
if min(isnan(LITHO.thickness(:)))==1 %all NaN values
    warning(['LITHO.zmax = ',num2str(LITHO.zmax),' too shallow: consider increasing!'])
end

if strcmp(GRID.Dim,'2-D')   % 2-D
    % get horizontal velocities at these depths
    vh_plate        = zeros(1,size(LITHO.gridpoints,1))*NaN;
    x2d_plate       = vh_plate;
    z2d_plate   	= vh_plate;
    for ix=1:size(LITHO.gridpoints,1)
        if isnan(LITHO.gridpoints(ix,1))
            vh_plate(1,ix) = NaN;
            x2d_plate(1,ix) = NaN; %with NaN values
            z2d_plate(1,ix) = NaN; %with NaN values
            continue
        end
        vh_plate(1,ix)  = VH_3D(ix,1,LITHO.gridpoints(ix,1));
        x2d_plate(1,ix) = x2d(ix,1,LITHO.gridpoints(ix,1)); %with NaN values
        z2d_plate(1,ix) = z2d(ix,1,LITHO.gridpoints(ix,1)); %with NaN values
    end

elseif strcmp(GRID.Dim,'3-D') %3-D
    % get normal stress at these depths
    vh_plate    = zeros(size(LITHO.gridpoints,1),size(LITHO.gridpoints,2))*NaN;
    x2d_plate  	= vh_plate;
    y2d_plate	= vh_plate;
    z2d_plate 	= vh_plate;
    for ix=1:size(LITHO.gridpoints,1)
        for iy=1:size(LITHO.gridpoints,2)
            if isnan(LITHO.gridpoints(ix,iy,1))
                vh_plate(ix,iy) = NaN;
                x2d_plate(ix,iy) = NaN; %with NaN values
                y2d_plate(ix,iy) = NaN; %with NaN values
                z2d_plate(ix,iy) = NaN; %with NaN values
                continue
            end
            vh_plate(ix,iy) = VH_3D(ix,iy,LITHO.gridpoints(ix,iy));
            x2d_plate(ix,iy) = x2d(ix,iy,LITHO.gridpoints(ix,iy)); %with NaN values
            y2d_plate(ix,iy) = y2d(ix,iy,LITHO.gridpoints(ix,iy)); %with NaN values
            z2d_plate(ix,iy) = z2d(ix,iy,LITHO.gridpoints(ix,iy)); %with NaN values
        end
    end
end
    
NanLocations = find(isnan(vh_plate));

%------------------------
% SMOOTHING  maybe doesn't work yet....
%------------------------
PLATE.Vh_smooth = logical(0); 
if strcmp(GRID.Dim,'2-D') && PLATE.Vh_smooth
    vh_smooth_1 = vh_plate;
    for jj=1:2
        vh_smooth_2(1,:) = smooth(vh_smooth_1(1,:),5,'moving');
        vh_smooth_1 = vh_smooth_2;
    end
    vh_plate = vh_smooth_2;
    
    %re-insert NaN values
    vh_plate(1,NanLocations) = NaN;
    %------------------------
end

%% WRITE INFOS
if PLOT.loop_field==1; display(['   > plate velocity   tracked at ~',num2str(mean(LITHO.thickness(:)),4),' km depth']); end
if PLOT.loop_field==1; display(['   >    and between d = ',num2str(min(LITHO.thickness(:)),4),' and ',num2str(max(LITHO.thickness(:)),4),' km depth']); end

%% COUNT SUBPLOTS
PLOT.nr_subplot = PLOT.nr_subplot+1;
nr_subplot = PLOT.nr_subplot;


% PLOT HORIZONTAL PLATE VELOCITY ---------------------------------------------------
if strcmp(GRID.Dim,'2-D')   % 2-D
    %% figure...
    figure(1)
    %% subplot...
    if isfield(PLOT,'subplotLayout') %manual arrangement
        sub_current=[PLOT.subplotLayout(1,1),PLOT.subplotLayout(1,2),nr_subplot];
    else
        if PLOT.nrPlots>=4
            if mod(PLOT.nrPlots,2)
                sub_current=[(PLOT.nrPlots+1)/2 2 nr_subplot];
            else
                sub_current=[PLOT.nrPlots/2 2 nr_subplot];
            end
        else
            sub_current=[PLOT.nrPlots 1 nr_subplot];
        end
    end
    if PLOT.reverseLayout %top-down plotting
        if ~isfield(PLOT,'layoutNum')
            PLOT.layoutNum = zeros(sub_current(1,1),sub_current(1,2));
            idx = 0;
            for ii=1:size(PLOT.layoutNum,1)
                for jj=1:size(PLOT.layoutNum,2)
                    idx = idx+1;
                    PLOT.layoutNum(ii,jj) = idx;
                end
            end
            idx = 0; PLOT.layoutNumTransposed = PLOT.layoutNum;
            for jj=1:size(PLOT.layoutNum,2)
                for ii=1:size(PLOT.layoutNum,1)
                    idx = idx+1;
                    PLOT.layoutNumTransposed(ii,jj) = idx; %transposed layout
                end
            end
        end
        %UPDATE TO NEW LAYOUT
        %       while PLOT.nr_subplot is still setup the old way!
        nr_subplot = PLOT.layoutNum(PLOT.layoutNumTransposed==nr_subplot);
        sub_current(1,3) = nr_subplot;
    end
    %% SUBPLOT
    subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3));
    %% CURRENT AXIS
    AXcurrent = gca; %save current axes handle
    
    %% PLOTTING HORIZONTAL PLATE VELOCITY ----------------------------------------------
    hold on
    PLATE.hLineVhplate = plot(x2d_plate,vh_plate,'Color',lineCOLOUR0,'LineWidth',lineWIDTH0);
    hold on
    
%     xpoints = x2d_plate;
%     upper = vh_plate;
%     if ~strcmp(TOPO.areaFill,'none')
%         if strcmp(TOPO.areaFill,'down')
%             color = lineCOLOUR0;
%             lower = zeros(size(upper))+(min(upper)-1/10*(max(upper)-min(upper)));
%             if TOPO.both && PLOT.topoLOWval<lower(1,1);
%                 lower = zeros(size(upper))+PLOT.topoLOWval;
%             end
%             if SWITCH.Colorbar(1,2); lower = zeros(size(upper))+FIELD.cColorbarMIN; end %constant colorbar
%             if SWITCH.plotDifference && strcmp(TOPO.difference,'diff'); lower = lower*0; end %in relation to 0 topography
%             
%         elseif strcmp(TOPO.areaFill,'updown')
%             color = lineCOLOUR0;
%             lower = zeros(size(upper));
%         else
%             error(['TOPO.areaFill mode ',TOPO.areaFill,'not recognised!'])
%         end
%     end

    
    %------------------------------------------------------------------
    fieldString1 = ['plate x-velocity @ ']; if PLOT.titleOnlyTime; fieldString1 = ''; end
    if SWITCH.dim || SWITCH.dimensional_input
        title_plot  = [fieldString1,num2str(PLOT.time2plot,3),' ',PLOT.time2plotDim];
        ylabel('vx-plate [cm/a]')
    else
        title_plot  = [fieldString1,num2str(PLOT.time,3),' '];
        ylabel('vx-plate [nd]')
    end
    xlabel(['width [',GRID.Xdim,']'])
    if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
    if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
        htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
    else
        htitle = title(title_plot); %centered
    end
    if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.nr_subplot,:)); end
    
    axis tight
    
    if SWITCH.Colorbar(1,2); ylim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
    if SWITCH.setAxisLimit
        if size(SWITCH.axisLimit,1)>1  %more than one axis-zoom value
            xlim(SWITCH.axisLimit(PLOT.loop_case,1:2));
        else
            xlim(SWITCH.axisLimit(1,1:2));
        end
    end
    %set(AXcurrent,'YGrid','on')
    grid on
    box on
    %set tickmarks out- or inside
    set(gca,'TickDir',SWITCH.tickDir)
    
    if SWITCH.texting
        if SWITCH.dim || SWITCH.dimensional_input
            text(min(xlim),max(ylim),['min val: ',num2str(min(vh_plate(:)),2)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
            text(max(xlim),max(ylim),['max val: ',num2str(max(vh_plate(:)),2)],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
            display(['   max.vplate: ',num2str(max(vh_plate)),' / min.vplate: ',num2str(min(vh_plate))])
        else
        end
    end
    
    % FIGURE SIZE & POSITION ==================================
    figure(1)
    hold on
    
    % COLORBAR ==================================
    colorbar;   %define dummy colorbar
    cb = NaN; 	%this is a flag if no colorbar is used
    
    %SIMPLIFY FIGURE ==================================
    if SWITCH.simplify
        %SET AXES ASPECT RATIO ----
        XaxisAR = GRID.aspectRatio(1);
        YaxisAR = 1;
        ZaxisAR = 1;
        set(gca,'PlotBoxAspectRatio',[XaxisAR YaxisAR ZaxisAR])
        %--------------------------
        
        %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
        PLOT.spcurrent          = sub_current;
        PLOT.sp_chax            = AXcurrent;
        if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else PLOT.sp_chaxz = NaN; end
        PLOT.sp_ccb             = cb;   %colorbar handle
        PLOT.title              = title_plot;  	%title string
        
        [PLOT] = f_splayout(SWITCH,PLOT,GRID,FIELD);
    end
    
elseif strcmp(GRID.Dim,'3-D') %3-D
    AXcurrent = gca; %just to be defined
    
    xi_plot = x2d_plate(:,1,1);  %[km]
    yi_plot = y2d_plate(1,:,1);  %[km]
    zi_plot = vh_plate;  %[km]
%     if i_field==2 %plot topo smooth ==========================
%         F = [.05 .1 .05; .1 .4 .1; .05 .1 .05];
%         for jj=1:20 %smoothing
%             ZC = conv2(zi_plot,F,'same');
%             zi_plot=ZC;
%         end
%     end %plot topo smooth ==========================
    
    surf(yi_plot,xi_plot,zi_plot,'EdgeColor','none')
    % contour(xi,yi,zi)
    if ~TOPO.ascii
        axis ij
    end
    axis tight
    if SWITCH.dim || SWITCH.dimensional_input
        zlabel('plate velocity [cm/a]')
    else
        zlabel('plate velocity [nd]')
    end
    xlabel(['x-width [',GRID.Xdim,']'])
    ylabel(['y-width [',GRID.Ydim,']'])
    if SWITCH.Colorbar(1,2); zlim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
    
    clearvars low high tix tiy
end



if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else nr_hax = 1; end

%% FUNCTION OUTPUT
PLOT.hax(nr_hax,1)  = AXcurrent;

%indicate axis handle as graph subplot
SAVE.graphPlotHandles = [SAVE.graphPlotHandles; AXcurrent]; %indicate axis handle as graph subplot
SAVE.PlotHandles = [SAVE.PlotHandles; AXcurrent];




    

