
%%   PLOT any temporal GRAPH

% Fabio Crameri, November 2015

%% NOTES
% nextfiletofind undefined..........
% sometimes 0th time step is missing and then it can't find the files....
% only for 2-D yet.................

function [PLOT,SAVE] = f_plotTimeGraph(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE)

%% INPUT
graph2plot          = {'upperPlateVel' 'lowerPlateVel' 'convergence'};  %chose between: trenchPos trenchVel upperPlateVel lowerPlateVel convergence
% graph2plot          = {'trenchVel'};  %chose between: trenchPos trenchVel upperPlateVel lowerPlateVel convergence
% graph2plot          = {'trenchPos'};  %chose between: trenchPos trenchVel upperPlateVel lowerPlateVel convergence
numMin              = 1;
numMax              = 9999;
indicateCurrentTime = logical(1);

%% FIND FILES TO PLOT
for ifiles=1:2
    if ifiles==1
        data2check = 'subZone';
    else
        data2check = 'time';
    end
    
    orgDir = pwd;
    fileNotFound = false; numMaxMin = 1e14;
    if ~exist([FILE.directory,'+data'],'dir')
        fileNotFound = true;
    else
        cd([FILE.directory,'+data'])
        filetofind      = [FILE.name,'_',data2check,num2str(numMax),'.mat'];
        % IF FILE NOT FOUND CHECK FOR LATEST FILE
        FILE.LastFile = false;
        if ~exist(filetofind,'file')
            % check for last output file number
            for io=numMin:numMax
                filetofind	= [FILE.name,'_',data2check,num2str(io),'.mat'];
                if ispc
                    filetofind       = strrep(filetofind,'/','\');
                end
                if ~exist(filetofind,'file') %&& io~=0 %sometimes 0 has no data
                    numMax=io-1; %update max number
                    break  %exit loop
                end
            end
            FILE.LastFile = true; %last file that exist reached
%         elseif ~exist(nextfiletofind,'file')
%             FILE.LastFile = true; %last file that exist reached
        end
        % ERROR MESSAGE IF NO FILE AT ALL IS NOT FOUND
        if numMax==-1
            fileNotFound = true;
            %error(['file not found - check file directory: ',filetofind])
        end
        cd(orgDir);
        numMaxMin = min(numMax,numMaxMin);
    end
end
numMax = numMaxMin;

if fileNotFound || strcmp(GRID.Dim,'3-D')
    %% EMPTY PLOT IF NO FILE FOUND
    [PLOT,SAVE] = f_emptyPlot(SWITCH,PLOT,GRID,FIELD,STYLE,SAVE);
    
else
    %% READ TIME DATA
    % Read time data produced by StagLab
    timeDat = zeros(numMax-numMin+1,3)*NaN;
    for number=numMin:numMax
        % TIME DATA:
        % [nd, seconds, years] %%%nd is later dimensionalised to whatever!
        dummy = [FILE.directory,'+data/',FILE.name,'_time',num2str(number),'.mat'];
        if ispc; dummy = strrep(dummy,'/','\'); end
        load(dummy);
        timeDat(number+1,1:3) = saveData;
    end
    
    %% READ GRAPH DATA
    % Read graph data produced by StagLab
    subZoneDat = zeros(numMax-numMin+1,5)*NaN;
    for number=numMin:numMax
        % SUBDUCTION ZONE DATA:
        % [x-trench, subduction-polarity, trench/UP-vel, LP-vel, Convergence-vel]
        dummy = [FILE.directory,'+data/',FILE.name,'_subZone',num2str(number),'.mat'];
        if ispc; dummy = strrep(dummy,'/','\'); end
        load(dummy);
        subZoneDat(number+1,:) = saveData(1,:);   %%%THIS READS ONLY ONE SUBDUCTION ZONE, MIGHT CREATE PROBLEMS WHEN MORE THAN 1 SUBDUCTION
    end
    
    %% TEST PLOT
    if logical(0)
        plot(timeDat(:,3),subZoneDat(:,3)); %plot trench velocity vs time
        plot(subZoneDat(:,1),timeDat(:,3)); %plot trench x position vs time
    end
    
    %% ERROR CHECKS
    if strcmp(GRID.Type,'cylindrical')
        % RE-FLIP DEPTH VECTOR AND ACCOUNT FOR STICKY-AIR LAYER
        z2d = z2d +SETUP.d_air*GRID.dimFactor;  %set z=0 to real surface
        z2d = 1*GRID.dimFactor -z2d; % reverse z-axis  (1.)
    end
    
    %% DIMENSIONALIZATION
    timeDat(:,1)        = timeDat(:,1) * PLOT.timeConvert; %t: [nd] to [whatever]
    subZoneDat(:,1)     = subZoneDat(:,1) * GRID.dimFactor; %x: [nd] to [whatever]
    % subZoneDat(:,3:5) 	= subZoneDat(:,3:5) * SETUP.Vscale; %v: [nd] to [whatever] %is already dimensional...
    
    %% DEFINE WHICH DATA TO PLOT
    fieldString1        = 'temporal evolution';
    
    iline = 0;
    if strcmp('trenchPos',graph2plot) %time on y-axis
        iline = iline+1;
        xdata           = subZoneDat(:,3);  %trench position
        xlabelString	= ['trench position [',GRID.Xdim,']'];
        ydata           = timeDat(:,1);     %plotting time
        ylabelString    = ['time [',PLOT.time2plotDim,']'];
        legendString	= [];
        timeAxis        = 'y'; %indicate on what axis time is
        
    else %time on x-axis
        if ismember('trenchVel',graph2plot)
            iline = iline+1;
            xdata(:,iline)          = timeDat(:,1);     %plotting time
            ydata(:,iline)          = subZoneDat(:,3);  %trench velocity
            legendString{iline,1}	= {'trench'};
            timeAxis                = 'x'; %indicate on what axis time is
        end
        if ismember('upperPlateVel',graph2plot)
            iline = iline+1;
            xdata(:,iline)           = timeDat(:,1);     %plotting time
            ydata(:,iline)           = subZoneDat(:,3);  %sub plate velocity
            legendString{iline,1}	= {'upper plate'};
            timeAxis(:,iline)        = 'x'; %indicate on what axis time is
        end
        if ismember('lowerPlateVel',graph2plot)
            iline = iline+1;
            xdata(:,iline)          = timeDat(:,1);     %plotting time
            ydata(:,iline)          = subZoneDat(:,4);  %sub plate velocity
            legendString{iline,1}	= {'lower plate'};
            timeAxis        = 'x'; %indicate on what axis time is
        end
        if ismember('convergence',graph2plot)
            iline = iline+1;
            xdata(:,iline)          = timeDat(:,1);     %plotting time
            ydata(:,iline)          = subZoneDat(:,5);  %convergence velocity
            legendString{iline,1}	= {'convergence'};
            timeAxis                = 'x'; %indicate on what axis time is
        end
        xlabelString    = ['time [',PLOT.time2plotDim,']'];
        ylabelString	= 'velocity [cm/a]';
    end
    
    %% SETUP FIGURE
    figure(1)
    
    %% COUNT SUBPLOTS
    PLOT.nr_subplot = PLOT.nr_subplot+1;
    nr_subplot = PLOT.nr_subplot;
    
    %% SETUP SUBPLOTS
    if isfield(PLOT,'subplotLayout') %manual arrangement
        sub_current=[PLOT.subplotLayout(1,1),PLOT.subplotLayout(1,2),nr_subplot];
    else
        if PLOT.nrPlots>=4
            if mod(PLOT.nrPlots,2)
                sub_current=[(PLOT.nrPlots+1)/2 2 nr_subplot];
            else
                sub_current=[PLOT.nrPlots/2 2 nr_subplot];
            end
        else
            sub_current=[PLOT.nrPlots 1 nr_subplot];
        end
    end
    if PLOT.reverseLayout %top-down plotting
        if ~isfield(PLOT,'layoutNum')
            PLOT.layoutNum = zeros(sub_current(1,1),sub_current(1,2));
            idx = 0;
            for ii=1:size(PLOT.layoutNum,1)
                for jj=1:size(PLOT.layoutNum,2)
                    idx = idx+1;
                    PLOT.layoutNum(ii,jj) = idx;
                end
            end
            idx = 0; PLOT.layoutNumTransposed = PLOT.layoutNum;
            for jj=1:size(PLOT.layoutNum,2)
                for ii=1:size(PLOT.layoutNum,1)
                    idx = idx+1;
                    PLOT.layoutNumTransposed(ii,jj) = idx; %transposed layout
                end
            end
        end
        %UPDATE TO NEW LAYOUT
        %       while PLOT.nr_subplot is still setup the old way!
        nr_subplot = PLOT.layoutNum(PLOT.layoutNumTransposed==nr_subplot);
        sub_current(1,3) = nr_subplot;
    end
    %% SET SUBPLOT
    subplot(sub_current(1,1),sub_current(1,2),sub_current(1,3));
    %% CURRENT AXIS
    AXcurrent = gca; %save current axes handle
    
    
    %% PLOTTING GRAPH VERSUS TIME
    hold on
    for iline=1:size(xdata,2)
        GRAPH.hLine(iline,1) = plot(xdata(:,iline),ydata(:,iline),'LineWidth',STYLE.keyLineWidth);
        if size(xdata,2)==1
            set(GRAPH.hLine(iline,1),'Color',STYLE.keyLineColor);
        end
        %     plot(timeDat(:,3),subZoneDat(:,3)); %plot trench velocity vs time
        %     plot(subZoneDat(:,1),timeDat(:,3)); %plot trench x position vs time
        hold on

        %MARKER FOR CURRENT TIME POSITION
        if indicateCurrentTime
            currentLineColor = get(GRAPH.hLine(iline,1),'Color');
            if strcmp(timeAxis,'x')
                dummy = round(xdata(:,iline),4)==round(PLOT.time2plot,4);
                xCurrentPoint = xdata(dummy,iline);
                yCurrentPoint = ydata(dummy,iline);
                if isempty(xCurrentPoint) %if time point is outside data range
                    xCurrentPoint = PLOT.time2plot;
                    yCurrentPoint = ydata(end,iline);
                end
            elseif strcmp(timeAxis,'y')
                dummy = round(ydata(:,iline),4)==round(PLOT.time2plot,4);
                xCurrentPoint = xdata(dummy,iline);
                yCurrentPoint = ydata(dummy,iline);
                if isempty(xCurrentPoint) %if time point is outside data range
                    xCurrentPoint = xdata(end,iline);
                    yCurrentPoint = PLOT.time2plot;
                end
            else
                error('time axis not specified: Check here!')
            end
            plot(xCurrentPoint,yCurrentPoint,'o',...
                'MarkerEdgeColor','none','MarkerFaceColor',currentLineColor);
        end
    end

    %     xpoints = x2d_plate;
    %     upper = vh_plate;
    %     if ~strcmp(TOPO.areaFill,'none')
    %         if strcmp(TOPO.areaFill,'down')
    %             color = STYLE.keyLineColor;
    %             lower = zeros(size(upper))+(min(upper)-1/10*(max(upper)-min(upper)));
    %             if TOPO.both && PLOT.topoLOWval<lower(1,1);
    %                 lower = zeros(size(upper))+PLOT.topoLOWval;
    %             end
    %             if SWITCH.Colorbar(1,2); lower = zeros(size(upper))+FIELD.cColorbarMIN; end %constant colorbar
    %             if SWITCH.plotDifference && strcmp(TOPO.difference,'diff'); lower = lower*0; end %in relation to 0 topography
    %
    %         elseif strcmp(TOPO.areaFill,'updown')
    %             color = STYLE.keyLineColor;
    %             lower = zeros(size(upper));
    %         else
    %             error(['TOPO.areaFill mode ',TOPO.areaFill,'not recognised!'])
    %         end
    %     end

    if ~isempty(legendString)
        legend(GRAPH.hLine,[legendString{:}]); %,'Location','NorthEast'
    end

    title_plot  = [fieldString1,' '];
    xlabel(xlabelString)
    ylabel(ylabelString)
    if isfield(PLOT,'titleString'); title_plot = PLOT.titleString(1,PLOT.nr_subplot); end
    if iscell(title_plot) && iscell(title_plot{1,1}) && size(title_plot{1,1},2)==2 %double-title
        htitle = title({title_plot{1,1}{1,1},title_plot{1,1}{1,2}}); %centered
    else
        htitle = title(title_plot); %centered
    end
    if isfield(PLOT,'titleColor'); set(htitle,'Color',PLOT.titleColor(PLOT.nr_subplot,:)); end

    axis tight

    if SWITCH.Colorbar(1,2); ylim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
    if SWITCH.setAxisLimit
        if size(SWITCH.axisLimit,1)>1  %more than one axis-zoom value
            xlim(SWITCH.axisLimit(PLOT.loop_case,1:2));
        else
            xlim(SWITCH.axisLimit(1,1:2));
        end
    end
    %set(AXcurrent,'YGrid','on')
    grid on
    box on
    %set tickmarks out- or inside
    set(gca,'TickDir',SWITCH.tickDir)

    if SWITCH.texting
        if SWITCH.dim || SWITCH.dimensional_input
            %             text(min(xlim),max(ylim),['min val: ',num2str(min(vh_plate(:)),2)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
            %             text(max(xlim),max(ylim),['max val: ',num2str(max(vh_plate(:)),2)],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
            %             display(['   max.vplate: ',num2str(max(vh_plate)),' / min.vplate: ',num2str(min(vh_plate))])
        else
        end
    end

    %% COLORBAR
    colorbar;   %define dummy colorbar
    cb = NaN; 	%this is a flag if no colorbar is used

    %% SIMPLIFY FIGURE
    if SWITCH.simplify
        %SET AXES ASPECT RATIO ----
        XaxisAR = GRID.aspectRatio(1);
        YaxisAR = 1;
        ZaxisAR = 1;
        set(gca,'PlotBoxAspectRatio',[XaxisAR YaxisAR ZaxisAR])
        %--------------------------

        %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
        PLOT.spcurrent          = sub_current;
        PLOT.sp_chax            = AXcurrent;
        if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else PLOT.sp_chaxz = NaN; end
        PLOT.sp_ccb             = cb;   %colorbar handle
        PLOT.title              = title_plot;  	%title string

        [PLOT] = f_splayout(SWITCH,PLOT,GRID,FIELD);
    end


    
    if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else nr_hax = 1; end
    
    %% FUNCTION OUTPUT
    PLOT.hax(nr_hax,1)  = AXcurrent;
    
    %indicate axis handle as graph subplot
    SAVE.graphPlotHandles = [SAVE.graphPlotHandles; AXcurrent]; %indicate axis handle as graph subplot
    SAVE.PlotHandles = [SAVE.PlotHandles; AXcurrent];

end


    

